import { Container, FederatedPointerEvent, Optional, Size } from 'pixi.js';
import { Signal } from 'typed-signals';
import { BaseSliderOptions, SliderBase } from './SliderBase';
export type SliderOptions = BaseSliderOptions & {
    slider: Container | string;
    step?: number;
    value?: number;
};
/**
 * Creates a slider to select a single value.
 * @example
 * new Slider({
 *     bg: 'slider_bg.png',
 *     fill: 'slider.png',
 *     slider: 'slider.png',
 *     min: 0,
 *     max: 100,
 *     value: 50,
 * });
 *
 * singleSlider.onChange.connect((value) => {
 *     console.log(`Slider changed to ${value}`);
 * });
 */
export declare class Slider extends SliderBase {
    protected sliderOptions: SliderOptions;
    /** Fires when value is changing, on every move of slider. */
    onUpdate: Signal<(value: number) => void>;
    /** Fires when value changed, only when slider is released. */
    onChange: Signal<(value: number) => void>;
    constructor(options: SliderOptions);
    /** Return selected value. */
    get value(): number;
    /** Set selected value. */
    set value(value: number);
    set max(value: number);
    get max(): number;
    set min(value: number);
    get min(): number;
    set step(value: number);
    get step(): number;
    /** Set slider instance ot texture. */
    set slider(value: Container | string);
    protected update(event: FederatedPointerEvent): void;
    protected change(): void;
    protected updateSlider(): void;
    /**
     * Sets width of a Sliders background and fill.
     * If nineSliceSprite is set, then width will be set to nineSliceSprite.
     * If nineSliceSprite is not set, then width will control components width as Container.
     * @param value - Width value.
     */
    set width(value: number);
    /** Gets width of a Slider. */
    get width(): number;
    /**
     * Sets height of a Sliders background and fill.
     * If nineSliceSprite is set, then height will be set to nineSliceSprite.
     * If nineSliceSprite is not set, then height will control components height as Container.
     * @param value - Height value.
     */
    set height(value: number);
    /** Gets height of a Slider. */
    get height(): number;
    setSize(value: number | Optional<Size, 'height'>, height?: number): void;
}
//# sourceMappingURL=Slider.d.ts.map