import { Container, FederatedPointerEvent, Texture } from 'pixi.js';
import { ProgressBar, ProgressBarOptions, ProgressBarViewType } from './ProgressBar';
import { PixiText, PixiTextClass, PixiTextStyle } from './utils/helpers/text';
import { type GetViewSettings } from './utils/helpers/view';
export type BaseSliderOptions = ProgressBarOptions & {
    min?: number;
    max?: number;
    valueTextStyle?: PixiTextStyle;
    valueTextClass?: PixiTextClass;
    showValue?: boolean;
    valueTextOffset?: {
        x?: number;
        y?: number;
    };
};
export type DoubleSliderOptions = BaseSliderOptions & {
    slider1?: Container | string;
    slider2?: Container | string;
    value1?: number;
    value2?: number;
};
/** Hepper class, used as a base for single or double slider creation. */
export declare class SliderBase extends ProgressBar {
    protected _slider1: Container;
    protected _slider2: Container;
    protected value1Text?: PixiText;
    protected value2Text?: PixiText;
    protected _value1: number;
    protected _value2: number;
    protected dragging: number;
    /** Minimal value. */
    protected _min: number;
    /** Maximal value. */
    protected _max: number;
    /** Progress value step */
    protected _step: number;
    protected startX: number;
    protected startUpdateValue1: number;
    protected startUpdateValue2: number;
    protected settings: DoubleSliderOptions;
    constructor(options: DoubleSliderOptions);
    init(progressBarOptions: ProgressBarOptions): void;
    /**
     * Sets Slider1 instance.
     * @param value - Container or string with texture name.
     */
    set slider1(value: Container | Texture | string);
    /** Get Slider1 instance. */
    get slider1(): Container;
    /**
     * Sets Slider2 instance.
     * @param value - Container or string with texture name.
     */
    set slider2(value: Container | string);
    /** Get Slider2 instance. */
    get slider2(): Container;
    /**
     * Set bg.
     * @param bg
     */
    setBackground(bg: ProgressBarViewType): void;
    protected activateBG(): void;
    protected createSlider(sliderData: GetViewSettings): Container;
    protected startUpdate(event: FederatedPointerEvent): void;
    protected endUpdate(): void;
    protected onClick(): void;
    protected update(_event: FederatedPointerEvent): void;
    /** Called when dragging stopped. */
    protected change(): void;
    /**
     * Set max value.
     * @param value
     */
    set max(value: number);
    /** Get max value. */
    get max(): number;
    /**
     * Set min value.
     * @param value
     */
    set min(value: number);
    /** Get min value. */
    get min(): number;
    /**
     * Set step value.
     * @param value
     */
    set step(value: number);
    /** Get step value. */
    get step(): number;
}
//# sourceMappingURL=SliderBase.d.ts.map